﻿using BlankProject.Utils;
using BlankProject.Views;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.ComponentModel;
using System.Runtime.CompilerServices;
using System.Windows.Input;
using Xamarin.Forms;

namespace BlankProject.ViewModels
{
    public class PageC1ViewModel : INotifyPropertyChanged
    {
        public event PropertyChangedEventHandler PropertyChanged;

        public ICommand UpdateListViewCommand { get; private set; }

        private ObservableCollection<ListViewGroup> _data;

        public ObservableCollection<ListViewGroup> Data
        {
            get { return _data; }
            set
            {
                if (value != _data)
                {
                    _data = value;
                    INotifyPropertyChanged();
                }
            }
        }

        public PageC1ViewModel()
        {
            UpdateListViewCommand = new Command(() => ExecUpdateListViewCommand());
            PrepareDataListView();
        }

        private void PrepareDataListView()
        {
            var item1 = new ListViewData()
            {
                Text = "Item 1"
            };

            var item2 = new ListViewData()
            {
                Text = "Item 2"
            };

            var item3 = new ListViewData()
            {
                Text = "Item 3"
            };

            var group1 = new ListViewGroup();
            group1.Title = "First group";
            group1.Add(item1);
            group1.Add(item2);
            group1.Add(item3);

            var groups = new ObservableCollection<ListViewGroup>();
            groups.Add(group1);

            Data = groups;
        }

        private void ExecUpdateListViewCommand()
        {
            var item4 = new ListViewData()
            {
                Text = "Item 4"
            };
            
            var item5 = new ListViewData()
            {
                Text = "Item 5"
            };

            Data[0].Add(item4);
            Data[0].Add(item5);
            Data[0][0].Text = "Item 1 OK";
        }

        public void INotifyPropertyChanged([CallerMemberName] string propertyName = "")
        {
            if (PropertyChanged != null)
            {
                PropertyChanged(this, new PropertyChangedEventArgs(propertyName));
            }
        }
    }
}
